@@ -129,8 +129,9 @@ void applier::ba::apply(const bam::configuration::state::bas& my_bas,
     _logger->info("BAM: removing BA {}", it->first);
     std::shared_ptr<io::data> s;
     if (bbdo3_enabled) {
-      auto bs = _ba_pb_service(it->first, it->second.cfg.get_host_id(),
-                               it->second.cfg.get_service_id());
+      auto bs = _ba_pb_service(
+          it->first, it->second.cfg.get_host_id(), it->second.cfg.get_name(),
+          it->second.cfg.get_host_name(), it->second.cfg.get_service_id());
       bs->mut_obj().set_enabled(false);
       s = bs;
     } else {
@@ -166,6 +167,7 @@ void applier::ba::apply(const bam::configuration::state::bas& my_bas,
     std::shared_ptr<io::data> s;
     if (bbdo3_enabled)
       s = _ba_pb_service(it->first, it->second.get_host_id(),
+                         it->second.get_name(), it->second.get_host_name(),
                          it->second.get_service_id());
     else
       s = _ba_service(it->first, it->second.get_host_id(),
@@ -296,6 +298,8 @@ std::shared_ptr<neb::service> applier::ba::_ba_service(uint32_t ba_id,
 std::shared_ptr<neb::pb_service> applier::ba::_ba_pb_service(
     uint32_t ba_id,
     uint32_t host_id,
+    const std::string& ba_name,
+    const std::string& host_name,
     uint32_t service_id,
     bool in_downtime) {
   _logger->trace("_ba_pb_service ba {}, service {}:{} with downtime {}", ba_id,
@@ -305,9 +309,10 @@ std::shared_ptr<neb::pb_service> applier::ba::_ba_pb_service(
   o.set_host_id(host_id);
   o.set_service_id(service_id);
   o.set_description(fmt::format("ba_{}", ba_id));
+  o.set_host_name(host_name);
   o.set_type(BA);
   o.set_internal_id(ba_id);
-  o.set_display_name(o.description());
+  o.set_display_name(ba_name);
   o.set_last_update(time(nullptr));
   o.set_scheduled_downtime_depth(in_downtime ? 1 : 0);
   o.set_max_check_attempts(1);
@@ -331,7 +336,7 @@ void applier::ba::_internal_copy(applier::ba const& other) {
  *
  *  @return New BA object.
  */
-std::shared_ptr<bam::ba> applier::ba::_new_ba(configuration::ba const& cfg,
+std::shared_ptr<bam::ba> applier::ba::_new_ba(const configuration::ba& cfg,
                                               service_book& book) {
   std::shared_ptr<bam::ba> obj;
   switch (cfg.get_state_source()) {
@@ -388,30 +393,6 @@ void applier::ba::save_to_cache(persistent_cache& cache) {
   }
 }
 
-/**
- *  Load inherited downtime from cache.
- *
- *  @param[in] cache  The cache.
- */
-void applier::ba::apply_inherited_downtime(const inherited_downtime& dwn) {
-  auto bbdo = config::applier::state::instance().get_bbdo_version();
-  bool bbdo3_enabled = bbdo.major_v >= 3;
-
-  std::map<uint32_t, applied>::iterator found = _applied.find(dwn.ba_id);
-  if (found != _applied.end()) {
-    _logger->debug("BAM: found an inherited downtime for BA {}", found->first);
-    found->second.obj->set_inherited_downtime(dwn);
-    std::shared_ptr<io::data> s;
-    if (bbdo3_enabled)
-      s = _ba_pb_service(found->first, found->second.cfg.get_host_id(),
-                         found->second.cfg.get_service_id(), dwn.in_downtime);
-    else
-      s = _ba_service(found->first, found->second.cfg.get_host_id(),
-                      found->second.cfg.get_service_id(), dwn.in_downtime);
-    multiplexing::publisher().write(s);
-  }
-}
-
 void applier::ba::apply_inherited_downtime(const pb_inherited_downtime& dwn) {
   auto bbdo = config::applier::state::instance().get_bbdo_version();
   bool bbdo3_enabled = bbdo.major_v >= 3;
@@ -421,11 +402,14 @@ void applier::ba::apply_inherited_downtime(const pb_inherited_downtime& dwn) {
     _logger->debug("BAM: found an inherited downtime for BA {}", found->first);
     found->second.obj->set_inherited_downtime(dwn);
     std::shared_ptr<io::data> s;
-    if (bbdo3_enabled)
-      s = _ba_pb_service(found->first, found->second.cfg.get_host_id(),
-                         found->second.cfg.get_service_id(),
-                         dwn.obj().in_downtime());
-    else
+    if (bbdo3_enabled) {
+      auto ss = std::make_shared<neb::pb_adaptive_service_status>();
+      auto& svc = ss->mut_obj();
+      svc.set_host_id(found->second.cfg.get_host_id());
+      svc.set_service_id(found->second.cfg.get_service_id());
+      svc.set_scheduled_downtime_depth(dwn.obj().in_downtime() ? 1 : 0);
+      s = ss;
+    } else
       s = _ba_service(found->first, found->second.cfg.get_host_id(),
                       found->second.cfg.get_service_id(),
                       dwn.obj().in_downtime());
