@@ -56,7 +56,7 @@ void (mysql_connection::*const mysql_connection::_task_processing_table[])(
 
 /**
  * @brief check if the error code is a server error. At the moment, we only
- * check two errors. Maybe we will need to add some.
+ * check three errors. Maybe we will need to add some.
  *
  * @param code the code to check
  *
@@ -66,6 +66,11 @@ bool mysql_connection::_server_error(int code) const {
   switch (code) {
     case CR_SERVER_GONE_ERROR:
     case CR_SERVER_LOST:
+      /* This last error has been seen with MySql when the server is behind
+       * a virtual IP and the VIP changes after an upgrade of the server. Broker
+       * does not know that the server has changed, so it tries to
+       * use a prepared statement that is not valid anymore. */
+    case ER_UNKNOWN_STMT_HANDLER:
       return true;
     default:
       return false;
@@ -466,14 +471,14 @@ void mysql_connection::_statement(mysql_task* t) {
                                         mysql_error::msg[task->error_code],
                                         err_code, ::mysql_stmt_error(stmt)));
         if (err_code == 0) {
-          SPDLOG_LOGGER_TRACE(_logger,
+          SPDLOG_LOGGER_ERROR(_logger,
                               "mysql_connection: errno=0, so we simulate a "
                               "server error CR_SERVER_LOST");
           err_code = CR_SERVER_LOST;
         } else {
-            SPDLOG_LOGGER_ERROR(_logger,
-                      "connection fail to execute statement {:p}: {}",
-                      static_cast<const void*>(this), err_msg);
+          SPDLOG_LOGGER_ERROR(_logger,
+                              "connection fail to execute statement {:p}: {}",
+                              static_cast<const void*>(this), err_msg);
         }
         if (_server_error(err_code)) {
           set_error_message(err_msg);
@@ -633,7 +638,7 @@ void mysql_connection::_statement_res(mysql_task* t) {
             res.set(prepare_meta_result);
             bind->set_empty();
           }
-          res.set_bind(move(bind));
+          res.set_bind(std::move(bind));
           task->promise.set_value(std::move(res));
         }
         break;
