@@ -17,10 +17,14 @@
  *
  */
 
-#include "com/centreon/broker/influxdb/line_protocol_query.hh"
 #include <gtest/gtest.h>
+
 #include "bbdo/storage/index_mapping.hh"
 #include "bbdo/storage/metric_mapping.hh"
+#include "com/centreon/broker/influxdb/line_protocol_query.hh"
+#include "com/centreon/broker/neb/host.hh"
+#include "com/centreon/broker/neb/instance.hh"
+#include "com/centreon/broker/neb/service.hh"
 #include "com/centreon/exceptions/msg_fmt.hh"
 #include "common/log_v2/log_v2.hh"
 
