@@ -1,26 +1,27 @@
-/*
-** Copyright 2011-2015,2017, 2020-2022 Centreon
-**
-** Licensed under the Apache License, Version 2.0 (the "License");
-** you may not use this file except in compliance with the License.
-** You may obtain a copy of the License at
-**
-**     http://www.apache.org/licenses/LICENSE-2.0
-**
-** Unless required by applicable law or agreed to in writing, software
-** distributed under the License is distributed on an "AS IS" BASIS,
-** WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-** See the License for the specific language governing permissions and
-** limitations under the License.
-**
-** For more information : contact@centreon.com
-*/
+/**
+ * Copyright 2011-2015,2017, 2020-2022 Centreon
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * For more information : contact@centreon.com
+ */
 
 #include "com/centreon/broker/rrd/output.hh"
 #include "com/centreon/broker/rrd/internal.hh"
 
 #include <absl/strings/str_join.h>
 #include <fmt/format.h>
+
 #include <cassert>
 #include <cstdlib>
 #include <iomanip>
@@ -30,18 +31,15 @@
 #include "bbdo/storage/status.hh"
 #include "com/centreon/broker/exceptions/shutdown.hh"
 #include "com/centreon/broker/io/events.hh"
-#include "com/centreon/broker/log_v2.hh"
-#include "com/centreon/broker/misc/perfdata.hh"
 #include "com/centreon/broker/rrd/exceptions/open.hh"
 #include "com/centreon/broker/rrd/exceptions/update.hh"
+#include "com/centreon/common/perfdata.hh"
+#include "common/log_v2/log_v2.hh"
 
 using namespace com::centreon::broker;
 using namespace com::centreon::broker::rrd;
 
-namespace com {
-namespace centreon {
-namespace broker {
-namespace rrd {
+namespace com::centreon::broker::rrd {
 
 template <class map_type>
 std::vector<typename map_type::key_type> keys_of_map(const map_type& data) {
@@ -88,8 +86,8 @@ output<lib>::output(std::string const& metrics_path,
       _status_path(status_path),
       _write_metrics(write_metrics),
       _write_status(write_status),
-      _backend(!metrics_path.empty() ? metrics_path : status_path, cache_size) {
-}
+      _backend(!metrics_path.empty() ? metrics_path : status_path, cache_size),
+      _logger{log_v2::instance().get(log_v2::RRD)} {}
 
 /**
  *  Local socket constructor.
@@ -119,7 +117,8 @@ output<cached<asio::local::stream_protocol::socket>>::output(
       _status_path(status_path),
       _write_metrics(write_metrics),
       _write_status(write_status),
-      _backend(metrics_path, cache_size) {
+      _backend(metrics_path, cache_size),
+      _logger{log_v2::instance().get(log_v2::RRD)} {
   _backend.connect_local(local);
 }
 
@@ -153,10 +152,7 @@ output<cached<asio::ip::tcp::socket>>::output(std::string const& metrics_path,
       _backend(metrics_path, cache_size) {
   _backend.connect_remote("localhost", port);
 }
-}  // namespace rrd
-}  // namespace broker
-}  // namespace centreon
-}  // namespace com
+}  // namespace com::centreon::broker::rrd
 
 /**
  *  Read data.
@@ -192,7 +188,7 @@ void output<T>::update() {
  */
 template <typename T>
 int output<T>::write(std::shared_ptr<io::data> const& d) {
-  SPDLOG_LOGGER_TRACE(log_v2::rrd(), "RRD: output::write.");
+  SPDLOG_LOGGER_TRACE(_logger, "RRD: output::write.");
   // Check that data exists.
   if (!validate(d, "RRD"))
     return 1;
@@ -204,8 +200,7 @@ int output<T>::write(std::shared_ptr<io::data> const& d) {
         std::shared_ptr<storage::pb_metric> e(
             std::static_pointer_cast<storage::pb_metric>(d));
         auto& m = e->obj();
-        SPDLOG_LOGGER_DEBUG(log_v2::rrd(),
-                            "RRD: new pb data for metric {} (time {})",
+        SPDLOG_LOGGER_DEBUG(_logger, "RRD: new pb data for metric {} (time {})",
                             m.metric_id(), m.time());
 
         // Metric path.
@@ -226,35 +221,33 @@ int output<T>::write(std::shared_ptr<io::data> const& d) {
           }
           std::string v;
           switch (m.value_type()) {
-            case misc::perfdata::gauge:
+            case Metric_ValueType_GAUGE:
               v = fmt::format("{:f}", m.value());
-              SPDLOG_LOGGER_TRACE(log_v2::rrd(),
+              SPDLOG_LOGGER_TRACE(_logger,
                                   "RRD: update metric {} of type GAUGE with {}",
                                   m.metric_id(), v);
               break;
-            case misc::perfdata::counter:
+            case Metric_ValueType_COUNTER:
               v = fmt::format("{}", static_cast<uint64_t>(m.value()));
               SPDLOG_LOGGER_TRACE(
-                  log_v2::rrd(),
-                  "RRD: update metric {} of type COUNTER with {}",
+                  _logger, "RRD: update metric {} of type COUNTER with {}",
                   m.metric_id(), v);
               break;
-            case misc::perfdata::derive:
+            case Metric_ValueType_DERIVE:
               v = fmt::format("{}", static_cast<int64_t>(m.value()));
               SPDLOG_LOGGER_TRACE(
-                  log_v2::rrd(), "RRD: update metric {} of type DERIVE with {}",
+                  _logger, "RRD: update metric {} of type DERIVE with {}",
                   m.metric_id(), v);
               break;
-            case misc::perfdata::absolute:
+            case Metric_ValueType_ABSOLUTE:
               v = fmt::format("{}", static_cast<uint64_t>(m.value()));
               SPDLOG_LOGGER_TRACE(
-                  log_v2::rrd(),
-                  "RRD: update metric {} of type ABSOLUTE with {}",
+                  _logger, "RRD: update metric {} of type ABSOLUTE with {}",
                   m.metric_id(), v);
               break;
             default:
               v = fmt::format("{:f}", m.value());
-              SPDLOG_LOGGER_TRACE(log_v2::rrd(),
+              SPDLOG_LOGGER_TRACE(_logger,
                                   "RRD: update metric {} of type {} with {}",
                                   m.metric_id(), m.value_type(), v);
               break;
@@ -270,9 +263,9 @@ int output<T>::write(std::shared_ptr<io::data> const& d) {
         // Debug message.
         std::shared_ptr<storage::metric> e(
             std::static_pointer_cast<storage::metric>(d));
-        SPDLOG_LOGGER_DEBUG(
-            log_v2::rrd(), "RRD: new data for metric {} (time {}) {}",
-            e->metric_id, e->time, e->is_for_rebuild ? "for rebuild" : "");
+        SPDLOG_LOGGER_DEBUG(_logger, "RRD: new data for metric {} (time {}) {}",
+                            e->metric_id, e->time,
+                            e->is_for_rebuild ? "for rebuild" : "");
 
         // Metric path.
         std::string metric_path(
@@ -292,35 +285,33 @@ int output<T>::write(std::shared_ptr<io::data> const& d) {
           }
           std::string v;
           switch (e->value_type) {
-            case misc::perfdata::gauge:
+            case common::perfdata::gauge:
               v = fmt::format("{:f}", e->value);
-              SPDLOG_LOGGER_TRACE(log_v2::rrd(),
+              SPDLOG_LOGGER_TRACE(_logger,
                                   "RRD: update metric {} of type GAUGE with {}",
                                   e->metric_id, v);
               break;
-            case misc::perfdata::counter:
+            case common::perfdata::counter:
               v = fmt::format("{}", static_cast<uint64_t>(e->value));
               SPDLOG_LOGGER_TRACE(
-                  log_v2::rrd(),
-                  "RRD: update metric {} of type COUNTER with {}", e->metric_id,
-                  v);
-              break;
-            case misc::perfdata::derive:
-              v = fmt::format("{}", static_cast<int64_t>(e->value));
-              SPDLOG_LOGGER_TRACE(
-                  log_v2::rrd(), "RRD: update metric {} of type DERIVE with {}",
+                  _logger, "RRD: update metric {} of type COUNTER with {}",
                   e->metric_id, v);
               break;
-            case misc::perfdata::absolute:
+            case common::perfdata::derive:
+              v = fmt::format("{}", static_cast<int64_t>(e->value));
+              SPDLOG_LOGGER_TRACE(
+                  _logger, "RRD: update metric {} of type DERIVE with {}",
+                  e->metric_id, v);
+              break;
+            case common::perfdata::absolute:
               v = fmt::format("{}", static_cast<uint64_t>(e->value));
               SPDLOG_LOGGER_TRACE(
-                  log_v2::rrd(),
-                  "RRD: update metric {} of type ABSOLUTE with {}",
+                  _logger, "RRD: update metric {} of type ABSOLUTE with {}",
                   e->metric_id, v);
               break;
             default:
               v = fmt::format("{:f}", e->value);
-              SPDLOG_LOGGER_TRACE(log_v2::rrd(),
+              SPDLOG_LOGGER_TRACE(_logger,
                                   "RRD: update metric {} of type {} with {}",
                                   e->metric_id, e->value_type, v);
               break;
@@ -337,7 +328,7 @@ int output<T>::write(std::shared_ptr<io::data> const& d) {
         std::shared_ptr<storage::pb_status> e(
             std::static_pointer_cast<storage::pb_status>(d));
         const auto& s = e->obj();
-        SPDLOG_LOGGER_DEBUG(log_v2::rrd(),
+        SPDLOG_LOGGER_DEBUG(_logger,
                             "RRD: new pb status data for index {} (state {})",
                             s.index_id(), s.state());
 
@@ -357,15 +348,21 @@ int output<T>::write(std::shared_ptr<io::data> const& d) {
             _backend.open(status_path, s.rrd_len(), s.time() - 1, interval);
           }
           std::string value;
-          if (s.state() == 0)
-            value = "100";
-          else if (s.state() == 1)
-            value = "75";
-          else if (s.state() == 2)
-            value = "0";
-          else
-            value = "";
-          _backend.update(s.time(), value);
+          switch (s.state()) {
+            case 0:
+              value = "100";
+              break;
+            case 1:
+              value = "75";
+              break;
+            case 2:
+              value = "0";
+              break;
+            default:
+              value = "U";
+              break;
+          }
+	  _backend.update(s.time(), value);
         } else
           // Cache value.
           it->second.push_back(d);
@@ -377,7 +374,7 @@ int output<T>::write(std::shared_ptr<io::data> const& d) {
         std::shared_ptr<storage::status> e(
             std::static_pointer_cast<storage::status>(d));
         SPDLOG_LOGGER_DEBUG(
-            log_v2::rrd(), "RRD: new status data for index {} (state {}) {}",
+            _logger, "RRD: new status data for index {} (state {}) {}",
             e->index_id, e->state, e->is_for_rebuild ? "for rebuild" : "");
 
         // Status path.
@@ -396,34 +393,38 @@ int output<T>::write(std::shared_ptr<io::data> const& d) {
             _backend.open(status_path, e->rrd_len, e->time - 1, interval);
           }
           std::string value;
-          if (e->state == 0)
-            value = "100";
-          else if (e->state == 1)
-            value = "75";
-          else if (e->state == 2)
-            value = "0";
-          else
-            value = "";
-          _backend.update(e->time, value);
+          switch (e->state) {
+            case 0:
+              value = "100";
+              break;
+            case 1:
+              value = "75";
+              break;
+            case 2:
+              value = "0";
+              break;
+            default:
+              value = "U";
+              break;
+          }
+	  _backend.update(e->time, value);
         } else
           // Cache value.
           it->second.push_back(d);
       }
       break;
     case storage::pb_rebuild_message::static_type(): {
-      SPDLOG_LOGGER_DEBUG(log_v2::rrd(), "RRD: RebuildMessage received");
+      SPDLOG_LOGGER_DEBUG(_logger, "RRD: RebuildMessage received");
       std::shared_ptr<storage::pb_rebuild_message> e{
           std::static_pointer_cast<storage::pb_rebuild_message>(d)};
       switch (e->obj().state()) {
         case RebuildMessage_State_START:
           if (e->obj().metric_to_index_id().empty()) {
-            SPDLOG_LOGGER_ERROR(log_v2::rrd(),
-                                "RRD: rebuild empty metric list");
+            SPDLOG_LOGGER_ERROR(_logger, "RRD: rebuild empty metric list");
             return 1;
           }
           SPDLOG_LOGGER_INFO(
-              log_v2::rrd(),
-              "RRD: Starting to rebuild metrics ({}) status ({})",
+              _logger, "RRD: Starting to rebuild metrics ({}) status ({})",
               fmt::join(keys_of_map(e->obj().metric_to_index_id()), ","),
               fmt::join(values_of_map(e->obj().metric_to_index_id()), ","));
           // Rebuild is starting.
@@ -447,22 +448,19 @@ int output<T>::write(std::shared_ptr<io::data> const& d) {
           break;
         case RebuildMessage_State_DATA:
           if (_metrics_rebuild.empty()) {
-            SPDLOG_LOGGER_ERROR(log_v2::rrd(),
-                                "RRD: rebuild empty metric list");
+            SPDLOG_LOGGER_ERROR(_logger, "RRD: rebuild empty metric list");
             return 1;
           }
-          SPDLOG_LOGGER_DEBUG(log_v2::rrd(), "RRD: Data to rebuild metrics");
+          SPDLOG_LOGGER_DEBUG(_logger, "RRD: Data to rebuild metrics");
           _rebuild_data(e->obj());
           break;
         case RebuildMessage_State_END:
           if (e->obj().metric_to_index_id().empty()) {
-            SPDLOG_LOGGER_ERROR(log_v2::rrd(),
-                                "RRD: rebuild empty metric list");
+            SPDLOG_LOGGER_ERROR(_logger, "RRD: rebuild empty metric list");
             return 1;
           }
           SPDLOG_LOGGER_INFO(
-              log_v2::rrd(),
-              "RRD: Finishing to rebuild metrics ({}) status ({})",
+              _logger, "RRD: Finishing to rebuild metrics ({}) status ({})",
               fmt::join(keys_of_map(e->obj().metric_to_index_id()), ","),
               fmt::join(values_of_map(e->obj().metric_to_index_id()), ","));
           // Rebuild is ending.
@@ -492,35 +490,35 @@ int output<T>::write(std::shared_ptr<io::data> const& d) {
           }
           break;
         default:
-          log_v2::rrd()->error(
+          _logger->error(
               "RRD: Bad 'state' value in rebuild message: it can only contain "
               "START, DATA or END");
           break;
       }
     } break;
     case storage::pb_remove_graph_message::static_type(): {
-      SPDLOG_LOGGER_DEBUG(log_v2::rrd(), "RRD: RemoveGraphsMessage received");
+      SPDLOG_LOGGER_DEBUG(_logger, "RRD: RemoveGraphsMessage received");
       std::shared_ptr<storage::pb_remove_graph_message> e{
           std::static_pointer_cast<storage::pb_remove_graph_message>(d)};
       for (auto& m : e->obj().metric_ids()) {
         std::string path{fmt::format("{}{}.rrd", _metrics_path, m)};
         /* File removed */
-        SPDLOG_LOGGER_INFO(log_v2::rrd(), "RRD: removing {} file", path);
+        SPDLOG_LOGGER_INFO(_logger, "RRD: removing {} file", path);
         _backend.remove(path);
       }
       for (auto& i : e->obj().index_ids()) {
         std::string path{fmt::format("{}{}.rrd", _status_path, i)};
         /* File removed */
-        SPDLOG_LOGGER_INFO(log_v2::rrd(), "RRD: removing {} file", path);
+        SPDLOG_LOGGER_INFO(_logger, "RRD: removing {} file", path);
         _backend.remove(path);
       }
     } break;
     case storage::remove_graph::static_type(): {
-      SPDLOG_LOGGER_INFO(log_v2::rrd(), "storage::remove_graph");
+      SPDLOG_LOGGER_INFO(_logger, "storage::remove_graph");
       // Debug message.
       std::shared_ptr<storage::remove_graph> e(
           std::static_pointer_cast<storage::remove_graph>(d));
-      SPDLOG_LOGGER_DEBUG(log_v2::rrd(), "RRD: remove graph request for {} {}",
+      SPDLOG_LOGGER_DEBUG(_logger, "RRD: remove graph request for {} {}",
                           e->is_index ? "index" : "metric", e->id);
 
       // Generate path.
@@ -537,8 +535,7 @@ int output<T>::write(std::shared_ptr<io::data> const& d) {
       _backend.remove(path);
     } break;
     default:
-      log_v2::rrd()->warn("RRD: unknown BBDO message received of type {}",
-                          d->type());
+      _logger->warn("RRD: unknown BBDO message received of type {}", d->type());
   }
 
   return 1;
@@ -593,7 +590,7 @@ void output<T>::_rebuild_data(const RebuildMessage& rm) {
 
   for (auto& p : rm.timeserie()) {
     std::deque<std::string> query;
-    SPDLOG_LOGGER_DEBUG(log_v2::rrd(), "RRD: Rebuilding metric {}", p.first);
+    SPDLOG_LOGGER_DEBUG(_logger, "RRD: Rebuilding metric {}", p.first);
     std::string path{fmt::format("{}{}.rrd", _metrics_path, p.first)};
     auto index_id_search = _metrics_to_index_rebuild.find(p.first);
     uint64_t index_id = 0;
@@ -603,15 +600,15 @@ void output<T>::_rebuild_data(const RebuildMessage& rm) {
 
     int32_t data_source_type = p.second.data_source_type();
     switch (data_source_type) {
-      case misc::perfdata::gauge:
+      case common::perfdata::gauge:
         for (auto& pt : p.second.pts()) {
           query.emplace_back(fmt::format("{}:{:f}", pt.ctime(), pt.value()));
           fill_status_request(index_id, p.second.check_interval(),
                               p.second.rrd_retention(), pt);
         }
         break;
-      case misc::perfdata::counter:
-      case misc::perfdata::absolute:
+      case common::perfdata::counter:
+      case common::perfdata::absolute:
         for (auto& pt : p.second.pts()) {
           query.emplace_back(fmt::format("{}:{}", pt.ctime(),
                                          static_cast<uint64_t>(pt.value())));
@@ -619,7 +616,7 @@ void output<T>::_rebuild_data(const RebuildMessage& rm) {
                               p.second.rrd_retention(), pt);
         }
         break;
-      case misc::perfdata::derive:
+      case common::perfdata::derive:
         for (auto& pt : p.second.pts()) {
           query.emplace_back(fmt::format("{}:{}", pt.ctime(),
                                          static_cast<int64_t>(pt.value())));
@@ -628,8 +625,7 @@ void output<T>::_rebuild_data(const RebuildMessage& rm) {
         }
         break;
       default:
-        SPDLOG_LOGGER_DEBUG(log_v2::rrd(),
-                            "data_source_type = {} is not managed",
+        SPDLOG_LOGGER_DEBUG(_logger, "data_source_type = {} is not managed",
                             data_source_type);
     }
 
@@ -643,7 +639,7 @@ void output<T>::_rebuild_data(const RebuildMessage& rm) {
         start_time = p.second.pts()[0].ctime() - interval;
       else
         start_time = std::time(nullptr) - interval;
-      SPDLOG_LOGGER_TRACE(log_v2::rrd(), "'{}' start date set to {}", path,
+      SPDLOG_LOGGER_TRACE(_logger, "'{}' start date set to {}", path,
                           start_time);
       try {
         /* Here, the file is opened only if it exists. */
@@ -653,16 +649,16 @@ void output<T>::_rebuild_data(const RebuildMessage& rm) {
         _backend.open(path, p.second.rrd_retention(), start_time, interval,
                       p.second.data_source_type(), true);
       }
-      SPDLOG_LOGGER_TRACE(log_v2::rrd(), "{} points added to file '{}'",
-                          query.size(), path);
+      SPDLOG_LOGGER_TRACE(_logger, "{} points added to file '{}'", query.size(),
+                          path);
       _backend.update(query);
 
     } else
-      SPDLOG_LOGGER_TRACE(log_v2::rrd(), "Nothing to rebuild in '{}'", path);
+      SPDLOG_LOGGER_TRACE(_logger, "Nothing to rebuild in '{}'", path);
   }
 
   for (const auto& by_index_status_values : status_values) {
-    SPDLOG_LOGGER_DEBUG(log_v2::rrd(), "RRD: Rebuilding status {}",
+    SPDLOG_LOGGER_DEBUG(_logger, "RRD: Rebuilding status {}",
                         by_index_status_values.first);
     std::string status_path{
         fmt::format("{}{}.rrd", _status_path, by_index_status_values.first)};
@@ -673,21 +669,21 @@ void output<T>::_rebuild_data(const RebuildMessage& rm) {
     try {
       /* Here, the file is opened only if it exists. */
       _backend.open(status_path);
-      SPDLOG_LOGGER_TRACE(log_v2::rrd(), "open '{}' start date set to {}",
+      SPDLOG_LOGGER_TRACE(_logger, "open '{}' start date set to {}",
                           status_path, start_time);
     } catch (const exceptions::open& b) {
       /* Here, the file is created. */
       _backend.open(status_path, by_index_status_values.second.rrd_retention,
                     start_time, by_index_status_values.second.check_interval, 0,
                     true);
-      SPDLOG_LOGGER_TRACE(log_v2::rrd(),
+      SPDLOG_LOGGER_TRACE(_logger,
                           "create '{}' start date set to {} retention set to "
                           "{}, check interval set to {}",
                           status_path, start_time,
                           by_index_status_values.second.rrd_retention,
                           by_index_status_values.second.check_interval);
     }
-    SPDLOG_LOGGER_TRACE(log_v2::rrd(), "{} points added to file '{}'",
+    SPDLOG_LOGGER_TRACE(_logger, "{} points added to file '{}'",
                         by_index_status_values.second.time_to_value.size(),
                         status_path);
 
