@@ -169,7 +169,7 @@ http_connection::pointer http_connection::load(
       fmt::format("{:p} " error_string, static_cast<void*>(this), *_conf, \
                   state_to_str(expected));                                \
   SPDLOG_LOGGER_ERROR(_logger, detail);                                   \
-  _io_context->post([cb = std::move(callback), detail]() {                \
+  asio::post(*_io_context, [cb = std::move(callback), detail]() {         \
     cb(std::make_error_code(std::errc::invalid_argument), detail);        \
   });                                                                     \
   return;
@@ -189,10 +189,18 @@ void http_connection::connect(connect_callback_type&& callback) {
                       *_conf);
   std::lock_guard<std::mutex> l(_socket_m);
   _socket.expires_after(_conf->get_connect_timeout());
-  _socket.async_connect(
-      _conf->get_endpoint(),
-      [me = shared_from_this(), cb = std::move(callback)](
-          const boost::beast::error_code& err) { me->on_connect(err, cb); });
+  if (_conf->get_endpoints().empty()) {
+    _socket.async_connect(
+        _conf->get_endpoint(),
+        [me = shared_from_this(), cb = std::move(callback)](
+            const boost::beast::error_code& err) { me->on_connect(err, cb); });
+  } else {
+    _socket.async_connect(_conf->get_endpoints(),
+                          [me = shared_from_this(), cb = std::move(callback)](
+                              const boost::beast::error_code& err,
+                              const typename asio::ip::tcp::endpoint& endpoint
+                              [[maybe_unused]]) { me->on_connect(err, cb); });
+  }
 }
 
 /**
@@ -236,7 +244,8 @@ void http_connection::on_connect(const boost::beast::error_code& err,
  * callback is useless in this case but is mandatory to have the same interface
  * than https_connection
  *
- * @param callback called via io_context::post (must have the same signature as https)
+ * @param callback called via io_context::post (must have the same signature as
+ * https)
  */
 void http_connection::_on_accept(connect_callback_type&& callback) {
   unsigned expected = e_not_connected;
@@ -249,8 +258,7 @@ void http_connection::_on_accept(connect_callback_type&& callback) {
 
   SPDLOG_LOGGER_DEBUG(_logger, "{:p} accepted from {}",
                       static_cast<void*>(this), _peer);
-
-  _io_context->post([cb = std::move(callback)]() { cb({}, ""); });
+  asio::post(*_io_context, [cb = std::move(callback)]() { cb({}, {}); });
 }
 
 void http_connection::init_keep_alive() {
@@ -282,7 +290,7 @@ void http_connection::init_keep_alive() {
       fmt::format("{:p}" error_string, static_cast<void*>(this), *_conf, \
                   state_to_str(expected));                               \
   SPDLOG_LOGGER_ERROR(_logger, detail);                                  \
-  _io_context->post([cb = std::move(callback), detail]() {               \
+  asio::post(*_io_context, [cb = std::move(callback), detail]() {        \
     cb(std::make_error_code(std::errc::invalid_argument), detail,        \
        response_ptr());                                                  \
   });                                                                    \
@@ -430,7 +438,7 @@ void http_connection::answer(const response_ptr& response,
         "answer to {}, bad state {}",
         static_cast<void*>(this), _peer, state_to_str(expected));
     SPDLOG_LOGGER_ERROR(_logger, detail);
-    _io_context->post([cb = std::move(callback), detail]() {
+    asio::post(*_io_context, [cb = std::move(callback), detail]() {
       cb(std::make_error_code(std::errc::invalid_argument), detail);
     });
     return;
@@ -476,7 +484,7 @@ void http_connection::receive_request(request_callback_type&& callback) {
         "receive_request from {}, bad state {}",
         static_cast<void*>(this), _peer, state_to_str(expected));
     SPDLOG_LOGGER_ERROR(_logger, detail);
-    _io_context->post([cb = std::move(callback), detail]() {
+    asio::post(*_io_context, [cb = std::move(callback), detail]() {
       cb(std::make_error_code(std::errc::invalid_argument), detail,
          std::shared_ptr<request_type>());
     });
