@@ -171,7 +171,7 @@ https_connection::pointer https_connection::load(
   std::string detail =                                             \
       fmt::format(error_string, *_conf, state_to_str(expected));   \
   SPDLOG_LOGGER_ERROR(_logger, detail);                            \
-  _io_context->post([cb = std::move(callback), detail]() {         \
+  asio::post(*_io_context, [cb = std::move(callback), detail]() {  \
     cb(std::make_error_code(std::errc::invalid_argument), detail); \
   });                                                              \
   return;
@@ -191,10 +191,19 @@ void https_connection::connect(connect_callback_type&& callback) {
                       *_conf);
   std::lock_guard<std::mutex> l(_socket_m);
   beast::get_lowest_layer(*_stream).expires_after(_conf->get_connect_timeout());
-  beast::get_lowest_layer(*_stream).async_connect(
-      _conf->get_endpoint(),
-      [me = shared_from_this(), cb = std::move(callback)](
-          const beast::error_code& err) mutable { me->on_connect(err, cb); });
+  if (_conf->get_endpoints().empty()) {
+    beast::get_lowest_layer(*_stream).async_connect(
+        _conf->get_endpoint(),
+        [me = shared_from_this(), cb = std::move(callback)](
+            const beast::error_code& err) mutable { me->on_connect(err, cb); });
+  } else {
+    beast::get_lowest_layer(*_stream).async_connect(
+        _conf->get_endpoints(),
+        [me = shared_from_this(), cb = std::move(callback)](
+            const beast::error_code& err,
+            const typename asio::ip::tcp::endpoint& endpoint
+            [[maybe_unused]]) mutable { me->on_connect(err, cb); });
+  }
 }
 
 /**
@@ -310,7 +319,7 @@ void https_connection::on_handshake(const beast::error_code err,
       fmt::format(error_string, static_cast<const void*>(this), *_conf, \
                   state_to_str(expected));                              \
   SPDLOG_LOGGER_ERROR(_logger, detail);                                 \
-  _io_context->post([cb = std::move(callback), detail]() {              \
+  asio::post(*_io_context, [cb = std::move(callback), detail]() {       \
     cb(std::make_error_code(std::errc::invalid_argument), detail,       \
        response_ptr());                                                 \
   });                                                                   \
@@ -453,7 +462,7 @@ void https_connection::answer(const response_ptr& response,
         "answer to {}, bad state {}",
         static_cast<void*>(this), _peer, state_to_str(expected));
     SPDLOG_LOGGER_ERROR(_logger, detail);
-    _io_context->post([cb = std::move(callback), detail]() {
+    asio::post(*_io_context, [cb = std::move(callback), detail]() {
       cb(std::make_error_code(std::errc::invalid_argument), detail);
     });
     return;
@@ -499,7 +508,7 @@ void https_connection::receive_request(request_callback_type&& callback) {
         "receive_request from {}, bad state {}",
         static_cast<void*>(this), _peer, state_to_str(expected));
     SPDLOG_LOGGER_ERROR(_logger, detail);
-    _io_context->post([cb = std::move(callback), detail]() {
+    asio::post(*_io_context, [cb = std::move(callback), detail]() {
       cb(std::make_error_code(std::errc::invalid_argument), detail,
          std::shared_ptr<request_type>());
     });
