@@ -30,7 +30,6 @@
 #include "com/centreon/engine/macros/grab_service.hh"
 #include "com/centreon/engine/neberrors.hh"
 #include "com/centreon/engine/string.hh"
-#include "com/centreon/exceptions/interruption.hh"
 
 using namespace com::centreon::engine;
 
@@ -1132,8 +1131,6 @@ bool anomalydetection::parse_perfdata(std::string const& perfdata,
   /* We should master this string, so no need to check if it is utf-8 */
   calculated_result.set_output(oss.str());
 
-  timestamp now(timestamp::now());
-
   // Update check result.
   timeval tv;
   gettimeofday(&tv, nullptr);
@@ -1402,7 +1399,7 @@ const std::string& anomalydetection::get_thresholds_file() const {
   return _thresholds_file;
 }
 
-void anomalydetection::resolve(int& w, int& e) {
+void anomalydetection::resolve(uint32_t& w, uint32_t& e) {
   set_check_period(_dependent_service->check_period());
   service::resolve(w, e);
 }
