@@ -1,22 +1,22 @@
 /**
-* Copyright 2003-2008      Ethan Galstad
-* Copyright 2011-2013,2016 Centreon
-*
-* This file is part of Centreon Engine.
-*
-* Centreon Engine is free software: you can redistribute it and/or
-* modify it under the terms of the GNU General Public License version 2
-* as published by the Free Software Foundation.
-*
-* Centreon Engine is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-* General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with Centreon Engine. If not, see
-* <http://www.gnu.org/licenses/>.
-*/
+ * Copyright 2003-2008      Ethan Galstad
+ * Copyright 2011-2013,2016 Centreon
+ *
+ * This file is part of Centreon Engine.
+ *
+ * Centreon Engine is free software: you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License version 2
+ * as published by the Free Software Foundation.
+ *
+ * Centreon Engine is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with Centreon Engine. If not, see
+ * <http://www.gnu.org/licenses/>.
+ */
 
 #ifdef HAVE_GETOPT_H
 #include <getopt.h>
@@ -27,9 +27,10 @@
 #include "com/centreon/engine/objects.hh"
 #include "com/centreon/engine/string.hh"
 #include "com/centreon/engine/version.hh"
-#include "com/centreon/exceptions/basic.hh"
+#include "com/centreon/exceptions/msg_fmt.hh"
 
 using namespace com::centreon::engine;
+using com::centreon::exceptions::msg_fmt;
 
 #define STATUS_NO_DATA 0
 #define STATUS_INFO_DATA 1
@@ -324,22 +325,19 @@ int main(int argc, char* argv[]) {
       if (stats_file) {
         if (read_stats_file() == ERROR) {
           char const* msg(strerror(errno));
-          throw(basic_error()
-                << "Error reading stats file '" << stats_file << "': " << msg);
+          throw msg_fmt("Error reading stats file '{}': {}", stats_file, msg);
         }
       }
       // Else read the normal status file.
       else {
         // Read main config file.
         if (read_config_file() == ERROR)
-          throw(basic_error()
-                << "Error processing config file '" << main_config_file);
+          throw msg_fmt("Error processing config file '{}'", main_config_file);
 
         // Read status file.
         if (read_status_file() == ERROR) {
           char const* msg(strerror(errno));
-          throw(basic_error() << "Error reading status file '" << status_file
-                              << "': " << msg);
+          throw msg_fmt("Error reading status file '{}': {}", status_file, msg);
         }
       }
 
@@ -1455,7 +1453,6 @@ void strip(char* buffer) {
       buffer[z - x] = buffer[z];
     buffer[y - x] = '\x0';
   }
-  return;
 }
 
 /* get days, hours, minutes, and seconds from a raw time_t format or total
@@ -1485,5 +1482,4 @@ void get_time_breakdown(unsigned long raw_time,
   *hours = temp_hours;
   *minutes = temp_minutes;
   *seconds = temp_seconds;
-  return;
 }
