@@ -24,6 +24,7 @@
 using namespace com::centreon::engine;
 using namespace com::centreon::engine::configuration;
 
+#ifdef LEGACY_CONF
 /**
  *  Apply new configuration.
  *
@@ -67,6 +68,51 @@ void applier::globals::apply(state& config) {
   ::use_large_installation_tweaks = config.use_large_installation_tweaks();
   ::instance_heartbeat_interval = config.instance_heartbeat_interval();
 }
+#else
+/**
+ *  Apply new configuration.
+ *
+ *  @param[in] config The new configuration.
+ */
+void applier::globals::apply(State& config) {
+  _set_global(::debug_file, config.debug_file());
+  _set_global(::global_host_event_handler, config.global_host_event_handler());
+  _set_global(::global_service_event_handler,
+              config.global_service_event_handler());
+  _set_global(::illegal_object_chars, config.illegal_object_chars());
+  _set_global(::illegal_output_chars, config.illegal_output_chars());
+  _set_global(::log_file, config.log_file());
+  _set_global(::ochp_command, config.ochp_command());
+  _set_global(::ocsp_command, config.ocsp_command());
+  _set_global(::use_timezone, config.use_timezone());
+
+  ::accept_passive_host_checks = config.accept_passive_host_checks();
+  ::accept_passive_service_checks = config.accept_passive_service_checks();
+  ::additional_freshness_latency = config.additional_freshness_latency();
+  ::cached_host_check_horizon = config.cached_host_check_horizon();
+  ::check_external_commands = config.check_external_commands();
+  ::check_host_freshness = config.check_host_freshness();
+  ::check_reaper_interval = config.check_reaper_interval();
+  ::check_service_freshness = config.check_service_freshness();
+  ::enable_event_handlers = config.enable_event_handlers();
+  ::enable_flap_detection = config.enable_flap_detection();
+  ::enable_notifications = config.enable_notifications();
+  ::execute_host_checks = config.execute_host_checks();
+  ::execute_service_checks = config.execute_service_checks();
+  ::interval_length = config.interval_length();
+  ::log_notifications = config.log_notifications();
+  ::log_passive_checks = config.log_passive_checks();
+  ::max_host_check_spread = config.max_host_check_spread();
+  ::max_service_check_spread = config.max_service_check_spread();
+  ::notification_timeout = config.notification_timeout();
+  ::obsess_over_hosts = config.obsess_over_hosts();
+  ::obsess_over_services = config.obsess_over_services();
+  ::process_performance_data = config.process_performance_data();
+  ::soft_state_dependencies = config.soft_state_dependencies();
+  ::use_large_installation_tweaks = config.use_large_installation_tweaks();
+  ::instance_heartbeat_interval = config.instance_heartbeat_interval();
+}
+#endif
 
 /**
  *  Get the singleton instance of globals applier.
