@@ -23,9 +23,11 @@
 #include "com/centreon/engine/string.hh"
 #include "com/centreon/engine/timeperiod.hh"
 #include "com/centreon/engine/timerange.hh"
+#include "common/engine_legacy_conf/daterange.hh"
 
 using namespace com::centreon::engine;
 
+#ifdef LEGACY_CONF
 /**
  *  Create a new exception to a timeperiod.
  *
@@ -42,10 +44,21 @@ using namespace com::centreon::engine;
  *  @param[in] ewday
  *  @param[in] ewday_offset
  *  @param[in] skip_interval
+ *  @param[in] a list of timeranges.
  */
-daterange::daterange(type_range type, int syear, int smon, int smday, int swday,
-                     int swday_offset, int eyear, int emon, int emday,
-                     int ewday, int ewday_offset, int skip_interval)
+daterange::daterange(type_range type,
+                     int syear,
+                     int smon,
+                     int smday,
+                     int swday,
+                     int swday_offset,
+                     int eyear,
+                     int emon,
+                     int emday,
+                     int ewday,
+                     int ewday_offset,
+                     int skip_interval,
+                     const std::list<configuration::timerange>& timeranges)
     : _type{type},
       _syear{syear},
       _smon{smon},
@@ -57,7 +70,60 @@ daterange::daterange(type_range type, int syear, int smon, int smday, int swday,
       _emday{emday},
       _ewday{ewday},
       _ewday_offset{ewday_offset},
-      _skip_interval{skip_interval} {}
+      _skip_interval{skip_interval} {
+  for (auto& tr : timeranges)
+    add_timerange({tr.range_start(), tr.range_end()});
+}
+#else
+/**
+ *  Create a new exception to a timeperiod.
+ *
+ *  @param[in] period        Base period.
+ *  @param[in] type
+ *  @param[in] syear
+ *  @param[in] smon
+ *  @param[in] smday
+ *  @param[in] swday
+ *  @param[in] swday_offset
+ *  @param[in] eyear
+ *  @param[in] emon
+ *  @param[in] emday
+ *  @param[in] ewday
+ *  @param[in] ewday_offset
+ *  @param[in] skip_interval
+ *  @param[in] a list of timeranges.
+ */
+daterange::daterange(
+    type_range type,
+    int syear,
+    int smon,
+    int smday,
+    int swday,
+    int swday_offset,
+    int eyear,
+    int emon,
+    int emday,
+    int ewday,
+    int ewday_offset,
+    int skip_interval,
+    const google::protobuf::RepeatedPtrField<configuration::Timerange>&
+        timeranges)
+    : _type{type},
+      _syear{syear},
+      _smon{smon},
+      _smday{smday},
+      _swday{swday},
+      _swday_offset{swday_offset},
+      _eyear{eyear},
+      _emon{emon},
+      _emday{emday},
+      _ewday{ewday},
+      _ewday_offset{ewday_offset},
+      _skip_interval{skip_interval} {
+  for (auto& tr : timeranges)
+    add_timerange({tr.range_start(), tr.range_end()});
+}
+#endif
 
 daterange::daterange(type_range type)
     : _type(type),
@@ -92,16 +158,6 @@ bool daterange::operator==(daterange const& obj) const {
          _timerange == obj._timerange;
 }
 
-bool daterange::is_date_data_equal(daterange const& obj) const {
-  return _type == obj.get_type() && _syear == obj.get_syear() &&
-         _smon == obj.get_smon() && _smday == obj.get_smday() &&
-         _swday == obj.get_swday() && _swday_offset == obj.get_swday_offset() &&
-         _eyear == obj.get_eyear() && _emon == obj.get_emon() &&
-         _emday == obj.get_emday() && _ewday == obj.get_ewday() &&
-         _ewday_offset == obj.get_ewday_offset() &&
-         _skip_interval == obj.get_skip_interval();
-}
-
 /**
  *  Not equal operator.
  *
@@ -114,41 +170,6 @@ bool daterange::operator!=(daterange const& obj) const {
   return !(*this == obj);
 }
 
-/**
- *  Less-than operator.
- *
- *  @param[in] right Object to compare to.
- *
- *  @return True if this object is less than right.
- */
-bool daterange::operator<(daterange const& right) const {
-  if (_emon != right._emon)
-    return (_emon < right._emon);
-  else if (_smon != right._smon)
-    return (_smon < right._smon);
-  else if (_emday != right._emday)
-    return (_emday < right._emday);
-  else if (_smday != right._smday)
-    return (_smday < right._smday);
-  else if (_skip_interval != right._skip_interval)
-    return (_skip_interval < right._skip_interval);
-  else if (_type != right._type)
-    return (_type < right._type);
-  else if (_ewday != right._ewday)
-    return (_ewday < right._ewday);
-  else if (_swday != right._swday)
-    return (_swday < right._swday);
-  else if (_ewday_offset != right._ewday_offset)
-    return (_ewday_offset < right._ewday_offset);
-  else if (_swday_offset != right._swday_offset)
-    return (_swday_offset < right._swday_offset);
-  else if (_eyear != right._eyear)
-    return (_eyear < right._eyear);
-  else if (_syear != right._syear)
-    return (_syear < right._syear);
-  return (_timerange < right._timerange);
-}
-
 /**
  *  Dump the daterange value into the calendar date format.
  *
@@ -167,7 +188,8 @@ static std::ostream& _dump_calendar_date(std::ostream& os,
     os << " - " << std::setfill('0') << std::setw(2) << obj.get_eyear() << "-"
        << std::setfill('0') << std::setw(2) << obj.get_emon() + 1 << "-"
        << std::setfill('0') << std::setw(2) << obj.get_emday();
-  if (obj.get_skip_interval()) os << " / " << obj.get_skip_interval();
+  if (obj.get_skip_interval())
+    os << " / " << obj.get_skip_interval();
   return (os);
 }
 
@@ -187,7 +209,8 @@ static std::ostream& _dump_month_date(std::ostream& os, daterange const& obj) {
     os << " - " << emon << " " << obj.get_emday();
   else if (obj.get_smday() != obj.get_emday())
     os << " - " << obj.get_emday();
-  if (obj.get_skip_interval()) os << " / " << obj.get_skip_interval();
+  if (obj.get_skip_interval())
+    os << " / " << obj.get_skip_interval();
   return (os);
 }
 
@@ -201,8 +224,10 @@ static std::ostream& _dump_month_date(std::ostream& os, daterange const& obj) {
  */
 static std::ostream& _dump_month_day(std::ostream& os, daterange const& obj) {
   os << "day " << obj.get_smday();
-  if (obj.get_smday() != obj.get_emday()) os << " - " << obj.get_emday();
-  if (obj.get_skip_interval()) os << " / " << obj.get_skip_interval();
+  if (obj.get_smday() != obj.get_emday())
+    os << " - " << obj.get_emday();
+  if (obj.get_skip_interval())
+    os << " / " << obj.get_skip_interval();
   return (os);
 }
 
@@ -226,7 +251,8 @@ static std::ostream& _dump_month_week_day(std::ostream& os,
     os << " - " << daterange::get_weekday_name(obj.get_ewday()) << " "
        << obj.get_ewday_offset() << " "
        << daterange::get_month_name(obj.get_emon());
-  if (obj.get_skip_interval()) os << " / " << obj.get_skip_interval();
+  if (obj.get_skip_interval())
+    os << " / " << obj.get_skip_interval();
   return (os);
 }
 
@@ -245,7 +271,8 @@ static std::ostream& _dump_week_day(std::ostream& os, daterange const& obj) {
       obj.get_swday_offset() != obj.get_ewday_offset())
     os << " - " << daterange::get_weekday_name(obj.get_ewday()) << " "
        << obj.get_ewday_offset();
-  if (obj.get_skip_interval()) os << " / " << obj.get_skip_interval();
+  if (obj.get_skip_interval())
+    os << " / " << obj.get_skip_interval();
   return (os);
 }
 
@@ -318,7 +345,8 @@ std::string const& daterange::get_month_name(unsigned int index) {
   static std::string const month[] = {
       "january", "february", "march",     "april",   "may",      "june",
       "july",    "august",   "september", "october", "november", "december"};
-  if (index >= sizeof(month) / sizeof(*month)) return (unknown);
+  if (index >= sizeof(month) / sizeof(*month))
+    return (unknown);
   return (month[index]);
 }
 
@@ -334,6 +362,7 @@ std::string const& daterange::get_weekday_name(unsigned int index) {
   static std::string const days[] = {"sunday",    "monday",   "tuesday",
                                      "wednesday", "thursday", "friday",
                                      "saturday"};
-  if (index >= sizeof(days) / sizeof(*days)) return (unknown);
+  if (index >= sizeof(days) / sizeof(*days))
+    return (unknown);
   return (days[index]);
 }
