@@ -19,13 +19,18 @@
 
 #include "com/centreon/engine/diagnostic.hh"
 #include <sys/stat.h>
-#include "com/centreon/engine/configuration/parser.hh"
-#include "com/centreon/engine/configuration/state.hh"
 #include "com/centreon/engine/exceptions/error.hh"
 #include "com/centreon/engine/logging/logger.hh"
 #include "com/centreon/engine/version.hh"
 #include "com/centreon/io/file_stream.hh"
 #include "com/centreon/process.hh"
+#ifdef LEGACY_CONF
+#include "common/engine_legacy_conf/parser.hh"
+#include "common/engine_legacy_conf/state.hh"
+#else
+#include "common/engine_conf/parser.hh"
+#include "common/engine_conf/state_helper.hh"
+#endif
 
 using namespace com::centreon;
 using namespace com::centreon::engine;
@@ -154,14 +159,27 @@ void diagnostic::generate(std::string const& cfg_file,
   // Parse configuration file.
   std::cout << "Diagnostic: Parsing configuration file '" << cfg_file << "'"
             << std::endl;
+#ifdef LEGACY_CONF
   configuration::state conf;
   try {
+    configuration::error_cnt err;
     configuration::parser parsr;
-    parsr.parse(cfg_file, conf);
+    parsr.parse(cfg_file, conf, err);
   } catch (std::exception const& e) {
     std::cerr << "Diagnostic: configuration file '" << cfg_file
               << "' parsing failed: " << e.what() << std::endl;
   }
+#else
+  configuration::State conf;
+  try {
+    configuration::error_cnt err;
+    configuration::parser parsr;
+    parsr.parse(cfg_file, &conf, err);
+  } catch (std::exception const& e) {
+    std::cerr << "Diagnostic: configuration file '" << cfg_file
+              << "' parsing failed: " << e.what() << std::endl;
+  }
+#endif
 
   // Create temporary configuration directory.
   std::string tmp_cfg_dir(tmp_dir + "/cfg/");
@@ -180,8 +198,7 @@ void diagnostic::generate(std::string const& cfg_file,
   }
 
   // Copy other configuration files.
-  for (std::list<std::string>::const_iterator it(conf.cfg_file().begin()),
-       end(conf.cfg_file().end());
+  for (auto it = conf.cfg_file().begin(), end = conf.cfg_file().end();
        it != end; ++it) {
     std::string target_path(_build_target_path(tmp_cfg_dir, *it));
     to_remove.push_back(target_path);
