@@ -44,7 +44,7 @@ timeperiod_map timeperiod::timeperiods;
  *  @param[in] alias Time period alias.
  *
  */
-
+#ifdef LEGACY_CONF
 timeperiod::timeperiod(std::string const& name, std::string const& alias)
     : _name{name}, _alias{alias} {
   if (name.empty() || alias.empty()) {
@@ -64,6 +64,94 @@ timeperiod::timeperiod(std::string const& name, std::string const& alias)
     throw engine_error() << "Could not register time period '" << name << "'";
   }
 }
+#else
+/**
+ * @brief Constructor of a timeperiod from its configuration protobuf object.
+ *
+ * @param obj The configuration protobuf object.
+ */
+timeperiod::timeperiod(const configuration::Timeperiod& obj)
+    : _name{obj.timeperiod_name()}, _alias{obj.alias()} {
+  if (_name.empty() || _alias.empty()) {
+    engine_logger(log_config_error, basic)
+        << "Error: Name or alias for timeperiod is NULL";
+    config_logger->error("Error: Name or alias for timeperiod is NULL");
+    throw engine_error() << "Could not register time period '" << _name << "'";
+  }
+
+  // Check if the timeperiod already exist.
+  timeperiod_map::const_iterator it{timeperiod::timeperiods.find(_name)};
+  if (it != timeperiod::timeperiods.end()) {
+    config_logger->error("Error: Timeperiod '{}' has already been defined",
+                         _name);
+    throw engine_error() << "Could not register time period '" << _name << "'";
+  }
+
+  // Fill time period structure.
+  for (auto& r : obj.timeranges().sunday())
+    days[0].emplace_back(r.range_start(), r.range_end());
+  for (auto& r : obj.timeranges().monday())
+    days[1].emplace_back(r.range_start(), r.range_end());
+  for (auto& r : obj.timeranges().tuesday())
+    days[2].emplace_back(r.range_start(), r.range_end());
+  for (auto& r : obj.timeranges().wednesday())
+    days[3].emplace_back(r.range_start(), r.range_end());
+  for (auto& r : obj.timeranges().thursday())
+    days[4].emplace_back(r.range_start(), r.range_end());
+  for (auto& r : obj.timeranges().friday())
+    days[5].emplace_back(r.range_start(), r.range_end());
+  for (auto& r : obj.timeranges().saturday())
+    days[6].emplace_back(r.range_start(), r.range_end());
+
+  auto fill_exceptions = [this](const auto& obj_daterange, int idx) {
+    for (auto& r : obj_daterange) {
+      exceptions[idx].emplace_back(static_cast<daterange::type_range>(r.type()),
+                                   r.syear(), r.smon(), r.smday(), r.swday(),
+                                   r.swday_offset(), r.eyear(), r.emon(),
+                                   r.emday(), r.ewday(), r.ewday_offset(),
+                                   r.skip_interval(), r.timerange());
+    }
+  };
+
+  fill_exceptions(obj.exceptions().calendar_date(), 0);
+  fill_exceptions(obj.exceptions().month_date(), 1);
+  fill_exceptions(obj.exceptions().month_day(), 2);
+  fill_exceptions(obj.exceptions().month_week_day(), 3);
+  fill_exceptions(obj.exceptions().week_day(), 4);
+
+  set_exclusions(obj.exclude());
+}
+
+void timeperiod::set_exclusions(const configuration::StringSet& exclusions) {
+  _exclusions.clear();
+  for (auto& s : exclusions.data())
+    _exclusions.emplace(s, nullptr);
+}
+
+void timeperiod::set_exceptions(const configuration::ExceptionArray& array) {
+  for (auto& e : exceptions)
+    e.clear();
+
+  auto fill_exceptions = [this](const auto& obj_daterange, int idx) {
+    for (auto& r : obj_daterange) {
+      //      std::list<timerange> tr;
+      //      for (auto& t : r.timerange())
+      //        tr.emplace_back(t.range_start(), t.range_end());
+      exceptions[idx].emplace_back(static_cast<daterange::type_range>(r.type()),
+                                   r.syear(), r.smon(), r.smday(), r.swday(),
+                                   r.swday_offset(), r.eyear(), r.emon(),
+                                   r.emday(), r.ewday(), r.ewday_offset(),
+                                   r.skip_interval(), r.timerange());
+    }
+  };
+
+  fill_exceptions(array.calendar_date(), 0);
+  fill_exceptions(array.month_date(), 1);
+  fill_exceptions(array.month_day(), 2);
+  fill_exceptions(array.month_week_day(), 3);
+  fill_exceptions(array.week_day(), 4);
+}
+#endif
 
 void timeperiod::set_name(std::string const& name) {
   _name = name;
@@ -85,7 +173,7 @@ bool timeperiod::operator==(timeperiod const& obj) noexcept {
   if (_name == obj._name && _alias == obj._alias &&
       (_exclusions.size() == obj._exclusions.size() &&
        std::equal(_exclusions.begin(), _exclusions.end(),
-                  obj._exclusions.begin()))) {
+                  obj._exclusions.begin(), obj._exclusions.end()))) {
     for (uint32_t i{0}; i < exceptions.size(); ++i)
       if (exceptions[i] != obj.exceptions[i])
         return false;
@@ -109,41 +197,6 @@ bool timeperiod::operator!=(timeperiod const& obj) noexcept {
   return !(*this == obj);
 }
 
-/**
- *  Dump timeperiod content into the stream.
- *
- *  @param[out] os  The output stream.
- *  @param[in]  obj The timeperiod to dump.
- *
- *  @return The output stream.
- */
-std::ostream& operator<<(std::ostream& os, timeperiod const& obj) {
-  os << "timeperiod {\n"
-     << "  name:  " << obj.get_name() << "\n"
-     << "  alias: " << obj.get_alias() << "\n"
-     << "  exclusions: " << obj.get_exclusions() << "\n";
-
-  for (uint32_t i = 0; i < obj.days.size(); ++i)
-    if (!obj.days[i].empty())
-      os << "  " << daterange::get_weekday_name(i) << ": " << obj.days[i]
-         << "\n";
-
-  for (uint32_t i = 0; i < obj.exceptions.size(); ++i)
-    for (daterange_list::const_iterator it(obj.exceptions[i].begin()),
-         end(obj.exceptions[i].end());
-         it != end; ++it)
-      os << "  " << *it << "\n";
-  os << "}\n";
-  return os;
-}
-
-std::ostream& operator<<(std::ostream& os, timeperiodexclusion const& obj) {
-  for (timeperiodexclusion::const_iterator it(obj.begin()), end(obj.end());
-       it != end; ++it)
-    os << it->first << (std::next(it) != obj.end() ? ", " : "");
-  return os;
-}
-
 /**
  *  Add a round number of days (expressed in seconds) to a date.
  *
@@ -1149,8 +1202,8 @@ void get_next_valid_time(time_t pref_time,
  * @param e[out] Number of errors produced during this resolution.
  *
  */
-void timeperiod::resolve(int& w __attribute__((unused)), int& e) {
-  int errors{0};
+void timeperiod::resolve(uint32_t& w __attribute__((unused)), uint32_t& e) {
+  uint32_t errors = 0;
 
   // Check for illegal characters in timeperiod name.
   if (contains_illegal_object_chars(_name.c_str())) {
@@ -1193,3 +1246,25 @@ void timeperiod::resolve(int& w __attribute__((unused)), int& e) {
     throw engine_error() << "Cannot resolve time period '" << _name << "'";
   }
 }
+
+#ifndef LEGACY_CONF
+void timeperiod::set_days(const configuration::DaysArray& array) {
+  for (auto& d : days)
+    d.clear();
+
+  for (auto& r : array.sunday())
+    days[0].emplace_back(r.range_start(), r.range_end());
+  for (auto& r : array.monday())
+    days[1].emplace_back(r.range_start(), r.range_end());
+  for (auto& r : array.tuesday())
+    days[2].emplace_back(r.range_start(), r.range_end());
+  for (auto& r : array.wednesday())
+    days[3].emplace_back(r.range_start(), r.range_end());
+  for (auto& r : array.thursday())
+    days[4].emplace_back(r.range_start(), r.range_end());
+  for (auto& r : array.friday())
+    days[5].emplace_back(r.range_start(), r.range_end());
+  for (auto& r : array.saturday())
+    days[6].emplace_back(r.range_start(), r.range_end());
+}
+#endif
