@@ -33,14 +33,17 @@
 #include "com/centreon/engine/configuration/applier/host.hh"
 #include "com/centreon/engine/configuration/applier/hostdependency.hh"
 #include "com/centreon/engine/configuration/applier/hostescalation.hh"
-#include "com/centreon/engine/configuration/host.hh"
-#include "com/centreon/engine/configuration/hostescalation.hh"
-#include "com/centreon/engine/configuration/state.hh"
 #include "com/centreon/engine/downtimes/downtime_manager.hh"
 #include "com/centreon/engine/exceptions/error.hh"
 #include "com/centreon/engine/globals.hh"
 #include "com/centreon/engine/retention/dump.hh"
 #include "com/centreon/engine/timezone_manager.hh"
+#ifdef LEGACY_CONF
+#include "common/engine_legacy_conf/host.hh"
+#include "common/engine_legacy_conf/hostescalation.hh"
+#include "common/engine_legacy_conf/state.hh"
+#else
+#endif
 
 using namespace com::centreon;
 using namespace com::centreon::engine;
@@ -56,16 +59,31 @@ class HostNotification : public TestEngine {
 
     events_logger->set_level(spdlog::level::off);
 
+    error_cnt err;
     configuration::applier::contact ct_aply;
+#ifdef LEGACY_CONF
     configuration::contact ctct{new_configuration_contact("admin", true)};
     ct_aply.add_object(ctct);
+#ifdef LEGACY_CONF
     ct_aply.expand_objects(*config);
-    ct_aply.resolve_object(ctct);
+#else
+    ct_aply.expand_objects(pb_config);
+#endif
+#else
+    configuration::Contact ctct{new_pb_configuration_contact("admin", true)};
+    ct_aply.add_object(ctct);
+    ct_aply.expand_objects(pb_config);
+#endif
+    ct_aply.resolve_object(ctct, err);
 
+#ifdef LEGACY_CONF
     configuration::host hst{new_configuration_host("test_host", "admin")};
+#else
+    configuration::Host hst{new_pb_configuration_host("test_host", "admin")};
+#endif
     configuration::applier::host hst_aply;
     hst_aply.add_object(hst);
-    hst_aply.resolve_object(hst);
+    hst_aply.resolve_object(hst, err);
     host_map const& hm{engine::host::hosts};
     _host = hm.begin()->second;
     _host->set_current_state(engine::host::state_up);
@@ -90,12 +108,12 @@ TEST_F(HostNotification, SimpleNormalHostNotification) {
    */
   set_time(43200);
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
+      new_timeperiod_with_timeranges("tperiod", "alias")};
   for (int i = 0; i < 7; ++i)
     tperiod->days[i].emplace_back(0, 86400);
 
   std::unique_ptr<engine::hostescalation> host_escalation{
-      new engine::hostescalation("host_name", 0, 1, 1.0, "tperiod", 7, Uuid())};
+      new engine::hostescalation("host_name", 0, 1, 1.0, "tperiod", 7, 12345)};
 
   ASSERT_TRUE(host_escalation);
   uint64_t id{_host->get_next_notification_id()};
@@ -114,15 +132,19 @@ TEST_F(HostNotification, SimpleNormalHostNotificationNotificationsdisabled) {
   /* We are using a local time() function defined in tests/timeperiod/utils.cc.
    * If we call time(), it is not the glibc time() function that will be called.
    */
+#ifdef LEGACY_CONF
   config->enable_notifications(false);
+#else
+  pb_config.set_enable_notifications(false);
+#endif
   set_time(43200);
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
+      new_timeperiod_with_timeranges("tperiod", "alias")};
   for (int i = 0; i < 7; ++i)
     tperiod->days[i].emplace_back(0, 86400);
 
   std::unique_ptr<engine::hostescalation> host_escalation{
-      new engine::hostescalation("host_name", 0, 1, 1.0, "tperiod", 7, Uuid())};
+      new engine::hostescalation("host_name", 0, 1, 1.0, "tperiod", 7, 12345)};
 
   ASSERT_TRUE(host_escalation);
   uint64_t id{_host->get_next_notification_id()};
@@ -139,12 +161,12 @@ TEST_F(HostNotification, SimpleNormalHostNotificationNotifierNotifdisabled) {
    */
   set_time(43200);
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
+      new_timeperiod_with_timeranges("tperiod", "alias")};
   for (int i = 0; i < 7; ++i)
     tperiod->days[i].emplace_back(0, 86400);
 
   std::unique_ptr<engine::hostescalation> host_escalation{
-      new engine::hostescalation("host_name", 0, 1, 1.0, "tperiod", 7, Uuid())};
+      new engine::hostescalation("host_name", 0, 1, 1.0, "tperiod", 7, 12345)};
 
   ASSERT_TRUE(host_escalation);
   uint64_t id{_host->get_next_notification_id()};
@@ -158,7 +180,7 @@ TEST_F(HostNotification, SimpleNormalHostNotificationNotifierNotifdisabled) {
 
 TEST_F(HostNotification, SimpleNormalHostNotificationOutsideTimeperiod) {
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
+      new_timeperiod_with_timeranges("tperiod", "alias")};
   set_time(20000);
 
   uint64_t id{_host->get_next_notification_id()};
@@ -166,7 +188,7 @@ TEST_F(HostNotification, SimpleNormalHostNotificationOutsideTimeperiod) {
     tperiod->days[i].emplace_back(43200, 86400);
 
   std::unique_ptr<engine::hostescalation> host_escalation{
-      new engine::hostescalation("host_name", 0, 1, 1.0, "", 7, Uuid())};
+      new engine::hostescalation("host_name", 0, 1, 1.0, "", 7, 12345)};
   _host->set_notification_period_ptr(tperiod.get());
 
   ASSERT_TRUE(host_escalation);
@@ -178,9 +200,13 @@ TEST_F(HostNotification, SimpleNormalHostNotificationOutsideTimeperiod) {
 
 TEST_F(HostNotification,
        SimpleNormalHostNotificationForcedWithNotificationDisabled) {
+#ifdef LEGACY_CONF
   config->enable_notifications(false);
+#else
+  pb_config.set_enable_notifications(false);
+#endif
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
+      new_timeperiod_with_timeranges("tperiod", "alias")};
   set_time(20000);
 
   uint64_t id{_host->get_next_notification_id()};
@@ -188,7 +214,7 @@ TEST_F(HostNotification,
     tperiod->days[i].emplace_back(43200, 86400);
 
   std::unique_ptr<engine::hostescalation> host_escalation{
-      new engine::hostescalation("host_name", 0, 1, 1.0, "", 7, Uuid())};
+      new engine::hostescalation("host_name", 0, 1, 1.0, "", 7, 12345)};
   _host->set_notification_period_ptr(tperiod.get());
 
   ASSERT_TRUE(host_escalation);
@@ -200,7 +226,7 @@ TEST_F(HostNotification,
 
 TEST_F(HostNotification, SimpleNormalHostNotificationForcedNotification) {
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
+      new_timeperiod_with_timeranges("tperiod", "alias")};
   set_time(20000);
 
   uint64_t id{_host->get_next_notification_id()};
@@ -208,7 +234,7 @@ TEST_F(HostNotification, SimpleNormalHostNotificationForcedNotification) {
     tperiod->days[i].emplace_back(43200, 86400);
 
   std::unique_ptr<engine::hostescalation> host_escalation{
-      new engine::hostescalation("host_name", 0, 1, 1.0, "", 7, Uuid())};
+      new engine::hostescalation("host_name", 0, 1, 1.0, "", 7, 12345)};
   _host->set_notification_period_ptr(tperiod.get());
 
   ASSERT_TRUE(host_escalation);
@@ -220,7 +246,7 @@ TEST_F(HostNotification, SimpleNormalHostNotificationForcedNotification) {
 
 TEST_F(HostNotification, SimpleNormalHostNotificationWithDowntime) {
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
+      new_timeperiod_with_timeranges("tperiod", "alias")};
   set_time(20000);
 
   _host->set_scheduled_downtime_depth(30);
@@ -229,7 +255,7 @@ TEST_F(HostNotification, SimpleNormalHostNotificationWithDowntime) {
     tperiod->days[i].emplace_back(0, 86400);
 
   std::unique_ptr<engine::hostescalation> host_escalation{
-      new engine::hostescalation("host_name", 0, 1, 1.0, "", 7, Uuid())};
+      new engine::hostescalation("host_name", 0, 1, 1.0, "", 7, 12345)};
   _host->set_notification_period_ptr(tperiod.get());
 
   ASSERT_TRUE(host_escalation);
@@ -241,7 +267,7 @@ TEST_F(HostNotification, SimpleNormalHostNotificationWithDowntime) {
 
 TEST_F(HostNotification, SimpleNormalHostNotificationWithFlapping) {
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
+      new_timeperiod_with_timeranges("tperiod", "alias")};
   set_time(20000);
 
   _host->set_is_flapping(true);
@@ -250,7 +276,7 @@ TEST_F(HostNotification, SimpleNormalHostNotificationWithFlapping) {
     tperiod->days[i].emplace_back(0, 86400);
 
   std::unique_ptr<engine::hostescalation> host_escalation{
-      new engine::hostescalation("host_name", 0, 1, 1.0, "", 7, Uuid())};
+      new engine::hostescalation("host_name", 0, 1, 1.0, "", 7, 12345)};
   _host->set_notification_period_ptr(tperiod.get());
 
   ASSERT_TRUE(host_escalation);
@@ -262,7 +288,7 @@ TEST_F(HostNotification, SimpleNormalHostNotificationWithFlapping) {
 
 TEST_F(HostNotification, SimpleNormalHostNotificationWithSoftState) {
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
+      new_timeperiod_with_timeranges("tperiod", "alias")};
   set_time(20000);
 
   _host->set_state_type(checkable::soft);
@@ -271,7 +297,7 @@ TEST_F(HostNotification, SimpleNormalHostNotificationWithSoftState) {
     tperiod->days[i].emplace_back(0, 86400);
 
   std::unique_ptr<engine::hostescalation> host_escalation{
-      new engine::hostescalation("host_name", 0, 1, 1.0, "", 7, Uuid())};
+      new engine::hostescalation("host_name", 0, 1, 1.0, "", 7, 12345)};
   _host->set_notification_period_ptr(tperiod.get());
 
   ASSERT_TRUE(host_escalation);
@@ -284,7 +310,7 @@ TEST_F(HostNotification, SimpleNormalHostNotificationWithSoftState) {
 TEST_F(HostNotification,
        SimpleNormalHostNotificationWithHardStateAcknowledged) {
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
+      new_timeperiod_with_timeranges("tperiod", "alias")};
   set_time(20000);
 
   uint64_t id{_host->get_next_notification_id()};
@@ -292,7 +318,7 @@ TEST_F(HostNotification,
     tperiod->days[i].emplace_back(0, 86400);
 
   std::unique_ptr<engine::hostescalation> host_escalation{
-      new engine::hostescalation("host_name", 0, 1, 1.0, "", 7, Uuid())};
+      new engine::hostescalation("host_name", 0, 1, 1.0, "", 7, 12345)};
   _host->set_notification_period_ptr(tperiod.get());
 
   _host->set_acknowledgement(AckType::NORMAL);
@@ -305,7 +331,7 @@ TEST_F(HostNotification,
 
 TEST_F(HostNotification, SimpleNormalHostNotificationAfterPreviousTooSoon) {
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
+      new_timeperiod_with_timeranges("tperiod", "alias")};
   set_time(20000);
 
   uint64_t id{_host->get_next_notification_id()};
@@ -313,7 +339,7 @@ TEST_F(HostNotification, SimpleNormalHostNotificationAfterPreviousTooSoon) {
     tperiod->days[i].emplace_back(0, 86400);
 
   std::unique_ptr<engine::hostescalation> host_escalation{
-      new engine::hostescalation("host_name", 0, 1, 1.0, "", 7, Uuid())};
+      new engine::hostescalation("host_name", 0, 1, 1.0, "", 7, 12345)};
   _host->set_notification_period_ptr(tperiod.get());
 
   _host->set_acknowledgement(AckType::NORMAL);
@@ -328,7 +354,7 @@ TEST_F(HostNotification, SimpleNormalHostNotificationAfterPreviousTooSoon) {
 TEST_F(HostNotification,
        SimpleNormalHostNotificationAfterPreviousWithNullInterval) {
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
+      new_timeperiod_with_timeranges("tperiod", "alias")};
   set_time(20000);
 
   uint64_t id{_host->get_next_notification_id()};
@@ -336,7 +362,7 @@ TEST_F(HostNotification,
     tperiod->days[i].emplace_back(0, 86400);
 
   std::unique_ptr<engine::hostescalation> host_escalation{
-      new engine::hostescalation("host_name", 0, 1, 1.0, "", 7, Uuid())};
+      new engine::hostescalation("host_name", 0, 1, 1.0, "", 7, 12345)};
   _host->set_notification_period_ptr(tperiod.get());
 
   _host->set_acknowledgement(AckType::NORMAL);
@@ -352,7 +378,7 @@ TEST_F(HostNotification,
 
 TEST_F(HostNotification, SimpleNormalHostNotificationOnStateNotNotified) {
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
+      new_timeperiod_with_timeranges("tperiod", "alias")};
   set_time(20000);
 
   uint64_t id{_host->get_next_notification_id()};
@@ -360,7 +386,7 @@ TEST_F(HostNotification, SimpleNormalHostNotificationOnStateNotNotified) {
     tperiod->days[i].emplace_back(0, 86400);
 
   std::unique_ptr<engine::hostescalation> host_escalation{
-      new engine::hostescalation("host_name", 0, 1, 1.0, "", 7, Uuid())};
+      new engine::hostescalation("host_name", 0, 1, 1.0, "", 7, 12345)};
   _host->set_notification_period_ptr(tperiod.get());
 
   _host->set_acknowledgement(AckType::NONE);
@@ -376,7 +402,7 @@ TEST_F(HostNotification, SimpleNormalHostNotificationOnStateNotNotified) {
 TEST_F(HostNotification,
        SimpleNormalHostNotificationOnStateBeforeFirstNotifDelay) {
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
+      new_timeperiod_with_timeranges("tperiod", "alias")};
   set_time(20000);
 
   uint64_t id{_host->get_next_notification_id()};
@@ -384,7 +410,7 @@ TEST_F(HostNotification,
     tperiod->days[i].emplace_back(0, 86400);
 
   std::unique_ptr<engine::hostescalation> host_escalation{
-      new engine::hostescalation("host_name", 0, 1, 1.0, "", 7, Uuid())};
+      new engine::hostescalation("host_name", 0, 1, 1.0, "", 7, 12345)};
   _host->set_notification_period_ptr(tperiod.get());
 
   _host->set_acknowledgement(AckType::NONE);
@@ -402,7 +428,7 @@ TEST_F(HostNotification,
 TEST_F(HostNotification,
        SimpleNormalHostNotificationOnStateAfterFirstNotifDelay) {
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
+      new_timeperiod_with_timeranges("tperiod", "alias")};
   set_time(20000);
 
   uint64_t id{_host->get_next_notification_id()};
@@ -410,7 +436,7 @@ TEST_F(HostNotification,
     tperiod->days[i].emplace_back(0, 86400);
 
   std::unique_ptr<engine::hostescalation> host_escalation{
-      new engine::hostescalation("host_name", 0, 1, 1.0, "", 7, Uuid())};
+      new engine::hostescalation("host_name", 0, 1, 1.0, "", 7, 12345)};
   _host->set_notification_period_ptr(tperiod.get());
 
   _host->set_acknowledgement(AckType::NONE);
@@ -430,12 +456,12 @@ TEST_F(HostNotification, SimpleNormalHostNotificationNotifierDelayTooShort) {
    */
   set_time(43200);
   std::unique_ptr<engine::timeperiod> tperiod{
-      new engine::timeperiod("tperiod", "alias")};
+      new_timeperiod_with_timeranges("tperiod", "alias")};
   for (uint32_t i = 0; i < tperiod->days.size(); ++i)
     tperiod->days[i].emplace_back(0, 86400);
 
   std::unique_ptr<engine::hostescalation> host_escalation{
-      new engine::hostescalation("host_name", 0, 1, 1.0, "tperiod", 7, Uuid())};
+      new engine::hostescalation("host_name", 0, 1, 1.0, "tperiod", 7, 12345)};
 
   ASSERT_TRUE(host_escalation);
   uint64_t id{_host->get_next_notification_id()};
@@ -557,25 +583,54 @@ TEST_F(HostNotification, CheckFirstNotificationDelay) {
 // Then contacts from the escalation are notified when notification number
 // is in [2,6] and are separated by at less 4*60s.
 TEST_F(HostNotification, HostEscalation) {
+  error_cnt err;
   configuration::applier::contact ct_aply;
+#ifdef LEGACY_CONF
   configuration::contact ctct{new_configuration_contact("test_contact", false)};
+#else
+  configuration::Contact ctct{
+      new_pb_configuration_contact("test_contact", false)};
+#endif
   ct_aply.add_object(ctct);
+#ifdef LEGACY_CONF
   ct_aply.expand_objects(*config);
-  ct_aply.resolve_object(ctct);
+#else
+  ct_aply.expand_objects(pb_config);
+#endif
+  ct_aply.resolve_object(ctct, err);
 
   configuration::applier::contactgroup cg_aply;
+#ifdef LEGACY_CONF
   configuration::contactgroup cg{
       new_configuration_contactgroup("test_cg", "test_contact")};
+#else
+  configuration::Contactgroup cg;
+  configuration::contactgroup_helper cg_hlp(&cg);
+  fill_pb_configuration_contactgroup(&cg_hlp, "test_cg", "test_contact");
+#endif
   cg_aply.add_object(cg);
+#ifdef LEGACY_CONF
   cg_aply.expand_objects(*config);
-  cg_aply.resolve_object(cg);
+#else
+  cg_aply.expand_objects(pb_config);
+#endif
+  cg_aply.resolve_object(cg, err);
 
   configuration::applier::hostescalation he_aply;
+#ifdef LEGACY_CONF
   configuration::hostescalation he{
       new_configuration_hostescalation("test_host", "test_cg")};
+#else
+  configuration::Hostescalation he{
+      new_pb_configuration_hostescalation("test_host", "test_cg")};
+#endif
   he_aply.add_object(he);
+#ifdef LEGACY_CONF
   he_aply.expand_objects(*config);
-  he_aply.resolve_object(he);
+#else
+  he_aply.expand_objects(pb_config);
+#endif
+  he_aply.resolve_object(he, err);
 
   int now{50000};
   set_time(now);
@@ -682,36 +737,70 @@ TEST_F(HostNotification, HostEscalation) {
 }
 
 TEST_F(HostNotification, HostDependency) {
+  error_cnt err;
   configuration::applier::contact ct_aply;
+#ifdef LEGACY_CONF
   configuration::contact ctct{new_configuration_contact("test_contact", false)};
+#else
+  configuration::Contact ctct{
+      new_pb_configuration_contact("test_contact", false)};
+#endif
   ct_aply.add_object(ctct);
+#ifdef LEGACY_CONF
   ct_aply.expand_objects(*config);
-  ct_aply.resolve_object(ctct);
+#else
+  ct_aply.expand_objects(pb_config);
+#endif
+  ct_aply.resolve_object(ctct, err);
 
   configuration::applier::contactgroup cg_aply;
+#ifdef LEGACY_CONF
   configuration::contactgroup cg{
       new_configuration_contactgroup("test_cg", "test_contact")};
+#else
+  configuration::Contactgroup cg;
+  configuration::contactgroup_helper cg_hlp(&cg);
+  fill_pb_configuration_contactgroup(&cg_hlp, "test_cg", "test_contact");
+#endif
   cg_aply.add_object(cg);
+#ifdef LEGACY_CONF
   cg_aply.expand_objects(*config);
-  cg_aply.resolve_object(cg);
+#else
+  cg_aply.expand_objects(pb_config);
+#endif
+  cg_aply.resolve_object(cg, err);
 
   configuration::applier::host h_aply;
+#ifdef LEGACY_CONF
   configuration::host h{new_configuration_host("dep_host", "admin", 15)};
+#else
+  configuration::Host h{new_pb_configuration_host("dep_host", "admin", 15)};
+#endif
   h_aply.add_object(h);
+#ifdef LEGACY_CONF
   h_aply.expand_objects(*config);
-  h_aply.resolve_object(h);
+#else
+  h_aply.expand_objects(pb_config);
+#endif
+  h_aply.resolve_object(h, err);
 
   configuration::applier::hostdependency hd_aply;
+#ifdef LEGACY_CONF
   configuration::hostdependency hd{
       new_configuration_hostdependency("test_host", "dep_host")};
   hd_aply.expand_objects(*config);
+#else
+  configuration::Hostdependency hd{
+      new_pb_configuration_hostdependency("test_host", "dep_host")};
+  hd_aply.expand_objects(pb_config);
+#endif
   hd_aply.add_object(hd);
-  hd_aply.resolve_object(hd);
+  hd_aply.resolve_object(hd, err);
 
   int now{50000};
   set_time(now);
 
-  int w{0}, e{0};
+  uint32_t w = 0, e = 0;
   pre_flight_circular_check(&w, &e);
 
   ASSERT_EQ(w, 0);
@@ -823,25 +912,52 @@ TEST_F(HostNotification, HostDependency) {
 // is sent 1 time
 // Then both are sent to contacts from the escalation.
 TEST_F(HostNotification, HostEscalationOneTime) {
+  error_cnt err;
   configuration::applier::contact ct_aply;
+#ifdef LEGACY_CONF
   configuration::contact ctct{new_configuration_contact("test_contact", false)};
   ct_aply.add_object(ctct);
   ct_aply.expand_objects(*config);
-  ct_aply.resolve_object(ctct);
+#else
+  configuration::Contact ctct{
+      new_pb_configuration_contact("test_contact", false)};
+  ct_aply.add_object(ctct);
+  ct_aply.expand_objects(pb_config);
+#endif
+  ct_aply.resolve_object(ctct, err);
 
   configuration::applier::contactgroup cg_aply;
+#ifdef LEGACY_CONF
   configuration::contactgroup cg{
       new_configuration_contactgroup("test_cg", "test_contact")};
+#else
+  configuration::Contactgroup cg;
+  configuration::contactgroup_helper cg_hlp(&cg);
+  fill_pb_configuration_contactgroup(&cg_hlp, "test_cg", "test_contact");
+#endif
   cg_aply.add_object(cg);
+#ifdef LEGACY_CONF
   cg_aply.expand_objects(*config);
-  cg_aply.resolve_object(cg);
+#else
+  cg_aply.expand_objects(pb_config);
+#endif
+  cg_aply.resolve_object(cg, err);
 
   configuration::applier::hostescalation he_aply;
+#ifdef LEGACY_CONF
   configuration::hostescalation he{
       new_configuration_hostescalation("test_host", "test_cg", 1, 0)};
+#else
+  configuration::Hostescalation he{
+      new_pb_configuration_hostescalation("test_host", "test_cg", 1, 0)};
+#endif
   he_aply.add_object(he);
+#ifdef LEGACY_CONF
   he_aply.expand_objects(*config);
-  he_aply.resolve_object(he);
+#else
+  he_aply.expand_objects(pb_config);
+#endif
+  he_aply.resolve_object(he, err);
 
   int now{50000};
   set_time(now);
@@ -918,25 +1034,54 @@ TEST_F(HostNotification, HostEscalationOneTime) {
 // is sent 1 time
 // Then both are sent to contacts from the escalation.
 TEST_F(HostNotification, HostEscalationOneTimeNotifInter0) {
+  error_cnt err;
   configuration::applier::contact ct_aply;
+#ifdef LEGACY_CONF
   configuration::contact ctct{new_configuration_contact("test_contact", false)};
+#else
+  configuration::Contact ctct{
+      new_pb_configuration_contact("test_contact", false)};
+#endif
   ct_aply.add_object(ctct);
+#ifdef LEGACY_CONF
   ct_aply.expand_objects(*config);
-  ct_aply.resolve_object(ctct);
+#else
+  ct_aply.expand_objects(pb_config);
+#endif
+  ct_aply.resolve_object(ctct, err);
 
   configuration::applier::contactgroup cg_aply;
+#ifdef LEGACY_CONF
   configuration::contactgroup cg{
       new_configuration_contactgroup("test_cg", "test_contact")};
+#else
+  configuration::Contactgroup cg;
+  configuration::contactgroup_helper cg_hlp(&cg);
+  fill_pb_configuration_contactgroup(&cg_hlp, "test_cg", "test_contact");
+#endif
   cg_aply.add_object(cg);
+#ifdef LEGACY_CONF
   cg_aply.expand_objects(*config);
-  cg_aply.resolve_object(cg);
+#else
+  cg_aply.expand_objects(pb_config);
+#endif
+  cg_aply.resolve_object(cg, err);
 
   configuration::applier::hostescalation he_aply;
+#ifdef LEGACY_CONF
   configuration::hostescalation he{
       new_configuration_hostescalation("test_host", "test_cg", 1, 0, 0)};
+#else
+  configuration::Hostescalation he{
+      new_pb_configuration_hostescalation("test_host", "test_cg", 1, 0, 0)};
+#endif
   he_aply.add_object(he);
+#ifdef LEGACY_CONF
   he_aply.expand_objects(*config);
-  he_aply.resolve_object(he);
+#else
+  he_aply.expand_objects(pb_config);
+#endif
+  he_aply.resolve_object(he, err);
 
   int now{50000};
   set_time(now);
@@ -1013,25 +1158,54 @@ TEST_F(HostNotification, HostEscalationOneTimeNotifInter0) {
 // is sent 1 time
 // Then both are sent to contacts from the escalation.
 TEST_F(HostNotification, HostEscalationRetention) {
+  error_cnt err;
   configuration::applier::contact ct_aply;
+#ifdef LEGACY_CONF
   configuration::contact ctct{new_configuration_contact("test_contact", false)};
+#else
+  configuration::Contact ctct{
+      new_pb_configuration_contact("test_contact", false)};
+#endif
   ct_aply.add_object(ctct);
+#ifdef LEGACY_CONF
   ct_aply.expand_objects(*config);
-  ct_aply.resolve_object(ctct);
+#else
+  ct_aply.expand_objects(pb_config);
+#endif
+  ct_aply.resolve_object(ctct, err);
 
   configuration::applier::contactgroup cg_aply;
+#ifdef LEGACY_CONF
   configuration::contactgroup cg{
       new_configuration_contactgroup("test_cg", "test_contact")};
+#else
+  configuration::Contactgroup cg;
+  configuration::contactgroup_helper cg_hlp(&cg);
+  fill_pb_configuration_contactgroup(&cg_hlp, "test_cg", "test_contact");
+#endif
   cg_aply.add_object(cg);
+#ifdef LEGACY_CONF
   cg_aply.expand_objects(*config);
-  cg_aply.resolve_object(cg);
+#else
+  cg_aply.expand_objects(pb_config);
+#endif
+  cg_aply.resolve_object(cg, err);
 
   configuration::applier::hostescalation he_aply;
+#ifdef LEGACY_CONF
   configuration::hostescalation he{
       new_configuration_hostescalation("test_host", "test_cg", 1, 0, 0)};
+#else
+  configuration::Hostescalation he{
+      new_pb_configuration_hostescalation("test_host", "test_cg", 1, 0, 0)};
+#endif
   he_aply.add_object(he);
+#ifdef LEGACY_CONF
   he_aply.expand_objects(*config);
-  he_aply.resolve_object(he);
+#else
+  he_aply.expand_objects(pb_config);
+#endif
+  he_aply.resolve_object(he, err);
 
   int now{50000};
   set_time(now);
