@@ -35,6 +35,7 @@ use POSIX ":sys_wait_h";
 use MIME::Base64;
 use Digest::MD5::File qw(file_md5_hex);
 use Archive::Tar;
+use Text::ParseWords;
 use Fcntl;
 use Try::Tiny;
 use EV;
@@ -387,14 +388,21 @@ sub action_command {
         }
 
         if ($self->is_command_authorized(command => $command->{command})) {
-            $self->{logger}->writeLogInfo("[action] command not allowed (whitelist): " . $command->{command});
+            my $commandtolog = $command->{command};
+            unless ($self->{logger}->is_debug()) {
+                my @commands = shellwords($command->{command});
+                $commandtolog = $commands[0];
+                $commandtolog .= ' ...' if @commands > 1;
+            }
+
+            $self->{logger}->writeLogError("[action] command not allowed (whitelist): " . $commandtolog);
             $self->send_log(
                 socket => $options{socket_log},
                 code => GORGONE_ACTION_FINISH_KO,
                 token => $options{token},
                 logging => $options{data}->{logging},
                 data => {
-                    message => "command not allowed (whitelist) at array index '" . $index . "'"
+                    message => "command not allowed (whitelist) at array index '$index' : $commandtolog"
                 }
             );
             return -1;
@@ -551,7 +559,7 @@ sub action_command {
 
 sub action_processcopy {
     my ($self, %options) = @_;
-    
+    my $dest_filename = $options{data}->{content}->{destination};
     if (!defined($options{data}->{content}) || $options{data}->{content} eq '') {
         $self->send_log(
             code => GORGONE_ACTION_FINISH_KO,
@@ -567,7 +575,10 @@ sub action_processcopy {
         my $fh;
         if (!sysopen($fh, $cache_file, O_RDWR|O_APPEND|O_CREAT, 0660)) {
             # no need to insert too many logs
-            return -1 if (defined($self->{process_copy_files_error}->{$cache_file}));
+            if (defined($self->{process_copy_files_error}->{$cache_file})) {
+                $self->{logger}->writeLogError("Error trying to add data to file $cache_file !");
+                return -1
+            }
             $self->{process_copy_files_error}->{$cache_file} = 1;
             $self->send_log(
                 code => GORGONE_ACTION_FINISH_KO,
@@ -596,19 +607,19 @@ sub action_processcopy {
                 message => 'process copy inprogress',
             }
         );
-        $self->{logger}->writeLogInfo("[action] Copy processing - Received chunk for '" . $options{data}->{content}->{destination} . "'");
+        $self->{logger}->writeLogInfo("[action] Copy processing - Received chunk for '" . $dest_filename . "'");
         return 0;
     } elsif ($options{data}->{content}->{status} eq 'end' && defined($options{data}->{content}->{md5})) {
         delete $self->{process_copy_files_error}->{$cache_file} if (defined($self->{process_copy_files_error}->{$cache_file}));
         my $local_md5_hex = file_md5_hex($cache_file);
         if (defined($local_md5_hex) && $options{data}->{content}->{md5} eq $local_md5_hex) {
             if ($options{data}->{content}->{type} eq "archive") {
-                if (! -d $options{data}->{content}->{destination}) {
-                    make_path($options{data}->{content}->{destination});
+                if (! -d $dest_filename) {
+                    make_path($dest_filename);
                 }
 
                 my $tar = Archive::Tar->new();
-                $tar->setcwd($options{data}->{content}->{destination});
+                $tar->setcwd($dest_filename);
                 unless ($tar->read($cache_file, undef, { extract => 1 })) {
                     my $tar_error = $tar->error();
                     $self->send_log(
@@ -622,7 +633,6 @@ sub action_processcopy {
                 }
             }
             elsif ($options{data}->{content}->{type} eq 'regular') {
-                my $dest_filename = $options{data}->{content}->{destination};
                 my $copy_status = copy($cache_file, $dest_filename);
                 if ($copy_status != 1){
                     $self->send_log(
@@ -658,7 +668,6 @@ sub action_processcopy {
             return -1;
         }
     }
-
     unlink($cache_file);
 
     $self->send_log(
@@ -669,7 +678,7 @@ sub action_processcopy {
             message => "process copy finished successfully",
         }
     );
-    $self->{logger}->writeLogInfo("[action] Copy processing - Copy to '" . $options{data}->{content}->{destination} . "' finished successfully");
+    $self->{logger}->writeLogInfo("[action] Copy processing - Copy to '" . $dest_filename . "' finished successfully");
     return 0;
 }
 
@@ -701,14 +710,21 @@ sub action_actionengine {
     }
 
     if ($self->is_command_authorized(command => $options{data}->{content}->{command})) {
-        $self->{logger}->writeLogInfo("[action] command not allowed (whitelist): " . $options{data}->{content}->{command});
+        my $commandtolog = $options{data}->{content}->{command};
+        unless ($self->{logger}->is_debug()) {
+            my @commands = shellwords($options{data}->{content}->{command});
+            $commandtolog = $commands[0];
+            $commandtolog .= ' ...' if @commands > 1;
+        }
+
+        $self->{logger}->writeLogError("[action] command not allowed (whitelist): " . $commandtolog);
         $self->send_log(
             socket => $options{socket_log},
             code => GORGONE_ACTION_FINISH_KO,
             token => $options{token},
             logging => $options{data}->{logging},
             data => {
-                message => 'command not allowed (whitelist)'
+                message => 'command not allowed (whitelist)' . $commandtolog
             }
         );
         return -1;
