@@ -1,10 +1,9 @@
 #!/usr/bin/python3
-from robot.api import logger
 import pymysql.cursors
 from robot.libraries.BuiltIn import BuiltIn
 
 
-BuiltIn().import_resource('db_variables.robot')
+BuiltIn().import_resource('db_variables.resource')
 DB_NAME_STORAGE = BuiltIn().get_variable_value("${DBName}")
 DB_NAME_CONF = BuiltIn().get_variable_value("${DBNameConf}")
 DB_USER_ROOT = BuiltIn().get_variable_value("${DBUserRoot}")
@@ -119,29 +118,28 @@ VALUES (1,'24x7','24_Hours_A_Day,_7_Days_A_Week','00:00-24:00','00:00-24:00','00
             if hosts % self.instances > 0:
                 r = 1
             v = int(hosts / self.instances) + r
-            last = hosts - (self.instances - 1) * v
             with connection.cursor() as cursor:
                 # Insertion of HOSTS COMMANDS
                 for i in range(1, self.hosts_count + 1):
-                    name = "checkh{}".format(i)
+                    name = f"checkh{i}"
                     cursor.execute(
-                        "INSERT INTO command (command_name,command_line) VALUES (\"{2}\",\"{0}/check.pl --id 0 --state {1}\")".format(ENGINE_HOME, i, name))
+                        f"INSERT INTO command (command_name,command_line) VALUES (\"{name}\",\"{ENGINE_HOME}/check.pl --id 0 --state {i}\")")
                     self.command[name] = cursor.lastrowid
                 connection.commit()
 
                 # Insertion of SERVICES COMMANDS
                 for i in range(1, self.commands_per_poller_count * self.instances + 1):
-                    name = "command_{}".format(i)
+                    name = f"command_{i}"
                     cursor.execute(
-                        "INSERT INTO command (command_name,command_line) VALUES (\"{2}\",\"{0}/check.pl --id {1}\")".format(ENGINE_HOME, i, name))
+                        f"INSERT INTO command (command_name,command_line) VALUES (\"{name}\",\"{ENGINE_HOME}/check.pl --id {i}\")")
                     self.command[name] = cursor.lastrowid
 
                 # Two specific commands
                 cursor.execute(
-                    "INSERT INTO command (command_name,command_line) VALUES (\"notif\",\"{}/notif.pl\")".format(ENGINE_HOME))
+                    f"INSERT INTO command (command_name,command_line) VALUES (\"notif\",\"{ENGINE_HOME}/notif.pl\")")
                 self.command["notif"] = cursor.lastrowid
                 cursor.execute(
-                    "INSERT INTO command (command_name,command_line) VALUES (\"test-notif\",\"{}/notif.pl\")".format(ENGINE_HOME))
+                    f"INSERT INTO command (command_name,command_line) VALUES (\"test-notif\",\"{ENGINE_HOME}/notif.pl\")")
                 self.command["test-notif"] = cursor.lastrowid
                 connection.commit()
 
@@ -235,13 +233,13 @@ VALUES (1,'24x7','24_Hours_A_Day,_7_Days_A_Week','00:00-24:00','00:00-24:00','00
 
     def ctn_create_ba(self, name: str, typ: str, critical_impact: int, warning_impact: int, dt_policy: str, activate:int = 1):
         """
-        create a ba in centreon db
+        Create a BA in the centreon database.
 
         Args:
-            name: name of ba
-            typ: best, worst, ratro_percent, ratio_number, impact
-            critical_impact: critical impact level
-            warning_impact: warning impact level
+            name: name of the BA
+            typ: One word among {best, worst, ratio_percent, ratio_number, impact}
+            critical_impact: Critical impact level
+            warning_impact: Warning impact level
             dt_policy: Downtime policy: inherit, ignore
             activate: 1 for enable, 0 for disable
         """
@@ -362,11 +360,11 @@ VALUES (1,'24x7','24_Hours_A_Day,_7_Days_A_Week','00:00-24:00','00:00-24:00','00
 
     def ctn_add_relations_ba_timeperiods(self, id_ba:int, id_time_period:int):
         """
-        add a line in mod_bam_relations_ba_timeperiods table
+        Add a line in mod_bam_relations_ba_timeperiods table
 
         Args:
-            id_ba: 
-            id_time_period:
+            id_ba: The ID of the BA.
+            id_time_period: The ID of the timeperiod.
         """
         connection = pymysql.connect(host=DB_HOST,
                                      user=DB_USER,
